pub struct StorageWriter { /* private fields */ }Expand description
A writer for storing data in chunks This allows efficient streaming writes without loading entire content into memory
Implementations
Sourceimpl StorageWriter
impl StorageWriter
Sourcepub async fn write_chunk(&mut self, chunk: &[u8]) -> Result<(), StorageError>
pub async fn write_chunk(&mut self, chunk: &[u8]) -> Result<(), StorageError>
Write a chunk of data to storage
Sourcepub async fn finish(self) -> Result<String, StorageError>
pub async fn finish(self) -> Result<String, StorageError>
Finish writing and return the storage location